CombinedIterableView<T> class
A view of several iterables combined sequentially into a single iterable.
All methods and accessors treat the CombinedIterableView as if it were a single concatenated iterable, but the underlying implementation is based on lazily accessing individual iterable instances. This means that if the underlying iterables change, the CombinedIterableView will reflect those changes.
- Inheritance
-
- Object
- IterableBase<
T> - CombinedIterableView
- Available extensions
- EnumByName
- FutureIterable
- HeartCollectionIterable
- HeartCollectionIterableString
- HeartIterable
- HeartIterableInt
- HeartIterableIterable
- HeartIterableNum
- HeartIterableOperator
- HeartIterableString
- IterableComparableExtension
- IterableDoubleExtension
- IterableExtension
- IterableExtensions
- IterableIntegerExtension
- IterableIterableExtension
- IterableNullableExtension
- IterableNumberExtension
- IterableToJSIterable
- NullableIterableExtensions
Constructors
-
CombinedIterableView(Iterable<
Iterable< _iterables)T> > -
Creates a combined view of
_iterables.const
Properties
-
ascending
→ Iterable<
E> -
Available on Iterable<
Returns a sorted iterable.E> , provided by the HeartIterable extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.num> , provided by the IterableNumberExtension extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.int> , provided by the IterableIntegerExtension extensionno setter - averageOrNull → double?
-
Available on Iterable<
Gets the average (mean) or returns null for an empty iterable.N> , provided by the HeartIterableNum extensionno setter -
backwards
→ Iterable<
E> -
Available on Iterable<
Reverses an iterable.E> , provided by the HeartIterable extensionno setter - chrs → String
-
Available on Iterable<
Returns a String from character codes.int> , provided by the HeartIterableInt extensionno setter -
descending
→ Iterable<
E> -
Available on Iterable<
Returns a sorted iterable in reverse order.E> , provided by the HeartIterable extensionno setter - first → T
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - firstOrNull → T?
-
Available on Iterable<
The first element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter -
flattened
→ Iterable<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToList
→ List<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToSet
→ Set<
T> -
Available on Iterable<
The unique sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- head → E?
-
Available on Iterable<
Returns the first element. Similar to .first, but returns null if there are no elements instead of throwing exception.E> , provided by the HeartIterable extensionno setter -
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter -
inits
→ Iterable<
Iterable< E> > -
Available on Iterable<
Returns a nested iterable by adding one element at a time, starting from the beginning.E> , provided by the HeartIterable extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setteroverride
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
T> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → T
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter - lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this Iterable.
no setteroverride
- max → int
-
Available on Iterable<
A maximal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - max → num
-
Available on Iterable<
A maximal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - max → T
-
Available on Iterable<
A maximal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - max → double
-
Available on Iterable<
A maximal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - maxOrNull → int?
-
Available on Iterable<
A maximal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullif the iterable is empty.no setter - maxOrNull → num?
-
Available on Iterable<
A maximal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullif the iterable is empty.no setter - maxOrNull → double?
-
Available on Iterable<
A maximal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullif the iterable is empty.no setter - maxOrNull → T?
-
Available on Iterable<
A maximal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullif the iterable is empty.no setter - medianOrNull → double?
-
Available on Iterable<
Returns the median of an iterable. Returns null if empty.N> , provided by the HeartIterableNum extensionno setter - min → T
-
Available on Iterable<
A minimal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - min → int
-
Available on Iterable<
A minimal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - min → num
-
Available on Iterable<
A minimal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - min → double
-
Available on Iterable<
A minimal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - minOrNull → double?
-
Available on Iterable<
A minimal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullit the iterable is empty.no setter - minOrNull → T?
-
Available on Iterable<
A minimal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullit the iterable is empty.no setter - minOrNull → int?
-
Available on Iterable<
A minimal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullit the iterable is empty.no setter - minOrNull → num?
-
Available on Iterable<
A minimal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullit the iterable is empty.no setter -
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - productOrNull → N?
-
Available on Iterable<
Multiplies all numbers of an iterable. Returns null if empty.N> , provided by the HeartIterableNum extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → T
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of the iterable, orT> , provided by the IterableExtension extensionnull.no setter - singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter - sum → int
-
Available on Iterable<
The sum of the elements.int> , provided by the IterableIntegerExtension extensionno setter - sum → double
-
Available on Iterable<
The sum of the elements.double> , provided by the IterableDoubleExtension extensionno setter - sum → num
-
Available on Iterable<
The sum of the elements.num> , provided by the IterableNumberExtension extensionno setter - sumOrNull → N?
-
Available on Iterable<
Sum of all numbers.N> , provided by the HeartIterableNum extensionno setter - sumOrNull → int?
-
Available on Iterable<
Sum of all numbers.int> , provided by the HeartIterableInt extensionno setter -
tail
→ Iterable<
E> ? -
Available on Iterable<
Removes the first element, keeps the "tail".E> , provided by the HeartIterable extensionno setter -
tails
→ Iterable<
Iterable< E> > -
Available on Iterable<
Returns a nested iterable by removing one element at a time, starting from the beginning.E> , provided by the HeartIterable extensionno setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
addMissing(
Iterable< E> elements, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Adds elements fromE> , provided by the HeartIterable extensionelementsthat are not in original value. -
after(
Iterable< E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Returns everything afterE> , provided by the HeartIterable extensionsub.1, 2, 3.after(1) returns (2, 3).1, 2, 3.after(1, 2) returns (3).1, 2, 3.after([]) returns (1, 2, 3). -
afterWhere(
bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) → Iterable< E> -
Available on Iterable<
Return everything after a condition is met.E> , provided by the HeartIterable extension1, 2, 3, 4.afterWhere((e) => e.isOdd) returns (2, 3, 4). -
any(
bool test(T element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
before(
Iterable< E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Returns everything before a given input:E> , provided by the HeartIterable extension1, 2, 3, 3.before(3, 3) returns (1, 2).1, 2, 3, 3.before(1) returns ().1, 2, 3, 3.before([]) returns (). -
beforeWhere(
bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) → Iterable< E> -
Available on Iterable<
Return everything before a condition is met.E> , provided by the HeartIterable extension1, 2, 3.beforeWhere((e) => e == 3) returns (1, 2). -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
concat(
) → String -
Available on Iterable<
Concatenate Strings together.String> , provided by the HeartIterableString extension -
concat(
) → Iterable< E> -
Available on Iterable<
Concatenate elements in nested iterable.Iterable< , provided by the HeartIterableIterable extensionE> > -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.override -
count(
Iterable< E> sub, {bool overlap = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → int -
Available on Iterable<
Count occurrences of elements occurring together, with option to includeE> , provided by the HeartIterable extensionoverlap. -
dec(
[N? decrementAmount]) → Iterable< N> -
Available on Iterable<
Decrement all values byN> , provided by the HeartIterableNum extensiondecrementAmount. -
deepContains(
Iterable< E> sub, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → bool -
Available on Iterable<
Returns true if iterable containsE> , provided by the HeartIterable extensionsub. -
div(
N divideBy) → Iterable< N> -
Available on Iterable<
Divide all values byN> , provided by the HeartIterableNum extensiondivideBy. -
div(
int divideBy) → Iterable< int> -
Available on Iterable<
Divide all values byint> , provided by the HeartIterableInt extensiondivideBy. -
dropIndices(
Iterable< int> indicesToDrop) → Iterable<E> -
Available on Iterable<
Removes the elements at the given indices.E> , provided by the HeartIterable extension -
elementAt(
int index) → T -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
elementAtOrNull(
int index) → T? -
Available on Iterable<
TheT> , provided by the IterableExtension extensionindexth element, ornullif there is no such element. -
every(
bool test(T element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(T element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
expandIndexed<
R> (Iterable< R> expand(int index, T element)) → Iterable<R> -
Available on Iterable<
Expands each element and index to a number of elements in a new iterable.T> , provided by the IterableExtension extension -
filter(
bool test(E element)) → Iterable< E> -
Available on Iterable<
.where equivalentE> , provided by the HeartCollectionIterable extension -
filterIndexed(
bool test(int index, E element)) → Iterable< E> -
Available on Iterable<
.whereIndexed equivalentE> , provided by the HeartCollectionIterable extension -
filterNot(
bool test(E element)) → Iterable< E> -
Available on Iterable<
.whereNot equivalentE> , provided by the HeartCollectionIterable extension -
filterNotIndexed(
bool test(int index, E element)) → Iterable< E> -
Available on Iterable<
.whereNotIndexed equivalentE> , provided by the HeartCollectionIterable extension -
filterType<
T> () → Iterable< T> -
Available on Iterable<
.whereType equivalent.E> , provided by the HeartCollectionIterable extension -
firstWhere(
bool test(T element), {T orElse()?}) → T -
The first element that satisfies the given predicate
test.inherited -
firstWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The first element whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
firstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The first element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
flatMap<
T> (Iterable< T> toElements(E element)) → Iterable<T> -
Available on Iterable<
.expand equivalentE> , provided by the HeartCollectionIterable extension -
flatMapIndexed<
R> (Iterable< R> expand(int index, E element)) → Iterable<R> -
Available on Iterable<
.expandIndexed equivalentE> , provided by the HeartCollectionIterable extension -
flatMapString(
Iterable< String> toElements(String)) → String -
Available on Iterable<
.expand equivalentString> , provided by the HeartCollectionIterableString extension -
flatMapStringIndexed(
Iterable< String> expand(int index, String element)) → String -
Available on Iterable<
.expandIndexed equivalentString> , provided by the HeartCollectionIterableString extension -
fold<
T> (T initialValue, T combine(T previousValue, T element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
foldIndexed<
R> (R initialValue, R combine(int index, R previous, T element)) → R -
Available on Iterable<
Combine the elements with a value and the current index.T> , provided by the IterableExtension extension -
followedBy(
Iterable< T> other) → Iterable<T> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(T element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
forEachIndexed(
void action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element.T> , provided by the IterableExtension extension -
forEachIndexedWhile(
bool action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element and index as long as desired.T> , provided by the IterableExtension extension -
forEachWhile(
bool action(T element)) → void -
Available on Iterable<
Takes an action for each element as long as desired.T> , provided by the IterableExtension extension -
frequencies(
{bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Map< E, int> -
Available on Iterable<
Return a Map that shows the frequencies of each element:E> , provided by the HeartIterable extension -
group(
{bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable< Iterable< E> > -
Available on Iterable<
Items are grouped together if they are equal to the one next to it.E> , provided by the HeartIterable extension -
groupBy(
bool groupFunction(dynamic a, dynamic b)) → Iterable< Iterable< E> > -
Available on Iterable<
Items are grouped together if they meet the criteria that compares consecutive elements.E> , provided by the HeartIterable extension -
groupFoldBy<
K, G> (K keyOf(T element), G combine(G? previous, T element)) → Map< K, G> -
Available on Iterable<
Groups elements byT> , provided by the IterableExtension extensionkeyOfthen folds the elements in each group. -
groupListsBy<
K> (K keyOf(T element)) → Map< K, List< T> > -
Available on Iterable<
Groups elements into lists byT> , provided by the IterableExtension extensionkeyOf. -
groupSetsBy<
K> (K keyOf(T element)) → Map< K, Set< T> > -
Available on Iterable<
Groups elements into sets byT> , provided by the IterableExtension extensionkeyOf. -
inc(
[N? incrementAmount]) → Iterable< N> -
Available on Iterable<
Increment all values byN> , provided by the HeartIterableNum extensionincrementAmount. -
indicesOf(
Iterable< E> sub, {bool overlap = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → List<int> -
Available on Iterable<
Finds every index where a sequence of elements occurs in an iterable, with option to includeE> , provided by the HeartIterable extensionoverlap. -
indicesWhere(
bool testFunction(E e)) → List< int> -
Available on Iterable<
Find all indices where a given condition is true.E> , provided by the HeartIterable extension -
insertInOrder(
Iterable< int> numbersToInsert) → Iterable<int> -
Available on Iterable<
Inserts each element inint> , provided by the HeartIterableInt extensionnumbersToInsertbefore the first element that is >= -
insertInOrder(
Iterable< N> numbersToInsert) → Iterable<N> -
Available on Iterable<
Inserts each element inN> , provided by the HeartIterableNum extensionnumbersToInsertbefore the first element that is >= -
intercalate(
Iterable< E> input, {int? count, int skip = 0, bool reverse = false}) → Iterable<E> -
Available on Iterable<
Inserts an iterable in between iterables and concatenates the result.Iterable< , provided by the HeartIterableIterable extensionE> > -
intercalate(
String input, {int? count, int skip = 0, bool reverse = false}) → String -
Available on Iterable<
Inserts a String between Strings and concatenates the result.String> , provided by the HeartIterableString extension -
interleave(
Iterable< E> it) → Iterable<E> -
Available on Iterable<
Combines elements by taking turns. First element in original iterable is the first element of the result.E> , provided by the HeartIterable extension -
intersperse(
Iterable< E> elementsToAdd, {int? count, int skip = 0, bool reverse = false}) → Iterable<E> -
Available on Iterable<
Inserts an element in between each element.E> , provided by the HeartIterable extension -
isSorted(
[Comparator< T> ? compare]) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableComparableExtension extensioncompareordering. -
isSorted(
Comparator< T> compare) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableExtension extensioncompareordering. -
isSortedBy<
K extends Comparable< (K> >K keyOf(T element)) → bool -
Available on Iterable<
Whether the elements are sorted by theirT> , provided by the IterableExtension extensionkeyOfproperty. -
isSortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → bool -
Available on Iterable<
Whether the elements areT> , provided by the IterableExtension extensioncompare-sorted by theirkeyOfproperty. -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
keep(
Iterable< E> elementsToKeep, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Keeps all elements that are also inE> , provided by the HeartIterable extensionelementsToKeep. -
keepIndices(
Iterable< int> indices) → Iterable<E> -
Available on Iterable<
Returns elements at the given indices.E> , provided by the HeartIterable extension -
lastBy<
K> (K key(T)) → Map< K, T> -
Available on Iterable<
Associates the elements inT> , provided by the IterableExtension extensionthisby the value returned bykey. -
lastWhere(
bool test(T element), {T orElse()?}) → T -
The last element that satisfies the given predicate
test.inherited -
lastWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The last element whose index and value satisfiesT> , provided by the IterableExtension extensiontest. -
lastWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The last element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
map<
T> (T toElement(T e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
mapIndexed<
R> (R convert(int index, T element)) → Iterable< R> -
Available on Iterable<
Maps each element and its index to a new value.T> , provided by the IterableExtension extension -
mode(
{bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable< E> -
Available on Iterable<
Returns the element(s) with the most occurrences.E> , provided by the HeartIterable extension -
mult(
N multiplyBy) → Iterable< N> -
Available on Iterable<
Multiply all values byN> , provided by the HeartIterableNum extensionmultiplyBy -
none(
bool test(T element)) → bool -
Available on Iterable<
Whether no element satisfiesT> , provided by the IterableExtension extensiontest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nub(
{Iterable< E> ? elementsToNub, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Removes duplicates.E> , provided by the HeartIterable extension -
reduce(
T combine(T value, T element)) → T -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
reduceIndexed(
T combine(int index, T previous, T element)) → T -
Available on Iterable<
Combine the elements with each other and the current index.T> , provided by the IterableExtension extension -
replace(
Iterable< E> from, Iterable<E> to, {int? count, int skip = 0, bool reverse = false, dynamic recursive = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
ReplaceE> , provided by the HeartIterable extensionfromwithto. -
riffleIn(
{bool inverse = false}) → Iterable< E> -
Available on Iterable<
Splits into two and uses interleave to combine, second half first.E> , provided by the HeartIterable extension -
riffleOut(
{bool inverse = false}) → Iterable< E> -
Available on Iterable<
Splits into two and uses interleave to combine.E> , provided by the HeartIterable extension -
sample(
int count, [Random? random]) → List< T> -
Available on Iterable<
SelectsT> , provided by the IterableExtension extensioncountelements at random from this iterable. -
shuffled(
[Random? random]) → List< T> -
Available on Iterable<
Creates a shuffled list of the elements of the iterable.T> , provided by the IterableExtension extension -
singleWhere(
bool test(T element), {T orElse()?}) → T -
The single element that satisfies
test.inherited -
singleWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
skip(
int count) → Iterable< T> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(T element)) → Iterable< T> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
slices(
int length) → Iterable< List< T> > -
Available on Iterable<
Contiguous slices ofT> , provided by the IterableExtension extensionthiswith the givenlength. -
sorted(
[Comparator< T> ? compare]) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableComparableExtension extension -
sorted(
Comparator< T> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sortedBy<
K extends Comparable< (K> >K keyOf(T element)) → List< T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
splitAfter(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements.T> , provided by the IterableExtension extension -
splitAfterIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements and indices.T> , provided by the IterableExtension extension -
splitAt(
int n) → Iterable< Iterable< E> > -
Available on Iterable<
Splits into two after firstE> , provided by the HeartIterable extensionnelements. -
splitBefore(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements.T> , provided by the IterableExtension extension -
splitBeforeIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements and indices.T> , provided by the IterableExtension extension -
splitBetween(
bool test(T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements.T> , provided by the IterableExtension extension -
splitBetweenIndexed(
bool test(int index, T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements and indices.T> , provided by the IterableExtension extension -
startsWith(
Iterable< E> sub, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → bool -
Available on Iterable<
Equivalent to Dart's .startsWith for String:E> , provided by the HeartIterable extension -
subtract(
Iterable< E> elementsToSubtract, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Removes elements one at a time if they are present.E> , provided by the HeartIterable extension -
subtractAll(
Iterable< E> elementsToRemove, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → Iterable<E> -
Available on Iterable<
Removes all elements if they are inE> , provided by the HeartIterable extensionelementsToRemove. -
take(
int count) → Iterable< T> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(T element)) → Iterable< T> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toDoubles(
) → Iterable< double> -
Available on Iterable<
Convert elements to doubles.N> , provided by the HeartIterableNum extension -
toInts(
) → Iterable< int> -
Available on Iterable<
Convert elements to truncated integers.N> , provided by the HeartIterableNum extension -
toList(
{bool growable = true}) → List< T> -
Creates a List containing the elements of this Iterable.
inherited
-
toRounded(
) → Iterable< int> -
Available on Iterable<
Convert elements to rounded integers.N> , provided by the HeartIterableNum extension -
toSet(
) → Set< T> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
Returns a string representation of (some of) the elements of
this.inherited -
toStrings(
) → Iterable< String> -
Available on Iterable<
Converts all elements to Strings.E> , provided by the HeartIterable extension -
transform<
T> (T toElement(E e)) → Iterable< T> -
Available on Iterable<
.map equivalentE> , provided by the HeartCollectionIterable extension -
transformIndexed<
R> (R convert(int index, E element)) → Iterable< R> -
Available on Iterable<
.mapIndexed equivalentE> , provided by the HeartCollectionIterable extension -
where(
bool test(T element)) → Iterable< T> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
whereNot(
bool test(T element)) → Iterable< T> -
Available on Iterable<
The elements that do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotNull(
) → Iterable< T> -
Available on Iterable<
The non-T?> , provided by the IterableNullableExtension extensionnullelements of thisIterable. -
whereType<
T> () → Iterable< R> -
Creates a new lazy Iterable with all elements that have type
T.inherited -
zip(
) → Iterable< String> -
Available on Iterable<
Pairs corresponding elements together.String> , provided by the HeartIterableString extension -
zip(
) → Iterable< Iterable< E> > -
Available on Iterable<
Pairs corresponding elements together.Iterable< , provided by the HeartIterableIterable extensionE> > -
zipWith<
R> (R zipFunction(List< String> )) → Iterable<R> -
Available on Iterable<
Perform a function between corresponding characters.String> , provided by the HeartIterableString extension -
zipWith<
R> (R zipFunction(List< E> )) → Iterable<R> -
Available on Iterable<
Returns an iterable by performing a function between corresponding elements of a nested iterable.Iterable< , provided by the HeartIterableIterable extensionE> >
Operators
-
operator *(
int n) → Iterable< E> -
Available on Iterable<
Repeat n times. Dart already does this for Strings.E> , provided by the HeartIterableOperator extension1, 2* 3 returns (1, 2, 1, 2, 1, 2). -
operator <(
Iterable it) → bool -
Available on Iterable<
Compare iterables element by element.E> , provided by the HeartIterableOperator extension1, 1, 3<1, 2, 3returns true because the second elements: 1 < 2.1, 'a'<1, 'b'returns true.1, 2<1, 2, 3returns true because first two elements are the same but the first iterable has shorter length. -
operator <=(
Iterable it) → bool -
Available on Iterable<
Returns true if < returns true or if equal length iterables have equal elements.E> , provided by the HeartIterableOperator extension1, 2<= {1, 2} returns true. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
Iterable it) → bool -
Available on Iterable<
Compare iterables element by element.E> , provided by the HeartIterableOperator extension -
operator >=(
Iterable it) → bool -
Available on Iterable<
Returns true if > returns true or if equal length iterables have equal elements.E> , provided by the HeartIterableOperator extension1, 2>=1, 2returns true.