head property
E?
get
head
Returns the first element. Similar to .first, but returns null if there are no elements instead of throwing exception.
Implementation
E? get head => h.headList(this);
Returns the first element. Similar to .first, but returns null if there are no elements instead of throwing exception.
E? get head => h.headList(this);