HeartQueueIterable<E> extension
Extension methods for iterables inside of a Queue
Methods
-
concat(
) → Queue< E> -
Available on Queue<
Concatenate elements in nested iterable.Iterable< , provided by the HeartQueueIterable extensionE> > -
intercalate(
Iterable< E> input, {int? count, int skip = 0, bool reverse = false}) → Queue<E> -
Available on Queue<
Inserts an iterable in between iterables and concatenates the result.Iterable< , provided by the HeartQueueIterable extensionE> > -
zip(
) → Queue< Queue< E> > -
Available on Queue<
Pairs corresponding elements together.Iterable< , provided by the HeartQueueIterable extensionE> > -
zipWith<
R> (R zipFunction(List< E> )) → Queue<R> -
Available on Queue<
Returns an iterable by performing a function between corresponding elements of a nested iterable.Iterable< , provided by the HeartQueueIterable extensionE> >