HeartQueueList<E> extension

Extension methods for QueueLists

on

Properties

ascending QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns a sorted iterable.
no setter
backwards QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Reverses a List
no setter
descending QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns a sorted iterable in reverse order.
no setter
inits QueueList<QueueList<E>>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns a nested iterable by adding one element at a time, starting from the beginning.
no setter
tail QueueList<E>?

Available on QueueList<E>, provided by the HeartQueueList extension

Removes the first element, keeps the "tail".
no setter
tails QueueList<QueueList<E>>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns a nested iterable by removing one element at a time, starting from the beginning.
no setter

Methods

addMissing(Iterable<E> elements, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Adds elements from elements that are not in original value.
after(Iterable<E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns everything after sub. 1, 2, 3.after(1) returns 2, 3. 1, 2, 3.after(1, 2) returns 3. 1, 2, 3.after([]) returns 1, 2, 3.
afterWhere(bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Return everything after a condition is met. 1, 2, 3, 4.afterWhere((e) => e.isOdd) returns 2, 3, 4.
before(Iterable<E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns everything before a given input: 1, 2, 3, 3.before(3, 3) returns 1, 2. 1, 2, 3, 3.before(1) returns []. 1, 2, 3, 3.before([]) returns [].
beforeWhere(bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Return everything before a condition is met. 1, 2, 3.beforeWhere((e) => e == 3) returns 1, 2.
dropIndices(Iterable<int> indicesToDrop) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Removes the elements at the given indices.
group({bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<QueueList<E>>

Available on QueueList<E>, provided by the HeartQueueList extension

Items are grouped together if they are equal to the one next to it.
groupBy(bool groupFunction(dynamic a, dynamic b)) QueueList<QueueList<E>>

Available on QueueList<E>, provided by the HeartQueueList extension

Items are grouped together if they meet the criteria that compares consecutive elements.
interleave(Iterable<E> it) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Combines elements by taking turns. First element in original iterable is the first element of the result.
intersperse(Iterable<E> elementsToAdd, {int? count, int skip = 0, bool reverse = false}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Inserts an element in between each element.
keep(Iterable<E> elementsToKeep, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Keeps all elements that are also in elementsToKeep.
keepIndices(Iterable<int> indices) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns elements at the given indices.
mode({bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Returns the element(s) with the most occurrences.
nub({Iterable<E>? elementsToNub, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Removes duplicates.
replace(Iterable<E> from, Iterable<E> to, {int? count, int skip = 0, bool reverse = false, dynamic recursive = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Replace from with to.
riffleIn({bool inverse = false}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Splits into two and uses interleave to combine, second half first.
riffleOut({bool inverse = false}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Splits into two and uses interleave to combine.
splitAt(int n) QueueList<QueueList<E>>

Available on QueueList<E>, provided by the HeartQueueList extension

Splits into two after first n elements.
subtract(Iterable<E> elementsToSubtract, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Removes elements one at a time if they are present.
subtractAll(Iterable<E> elementsToRemove, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) QueueList<E>

Available on QueueList<E>, provided by the HeartQueueList extension

Removes all elements if they are in elementsToRemove.
toStrings() QueueList<String>

Available on QueueList<E>, provided by the HeartQueueList extension

Converts all elements to Strings.