HeartQueueListIterable<E> extension

Extension methods for iterables inside of a QueueList

on

Methods

concat() QueueList<E>

Available on QueueList<Iterable<E>>, provided by the HeartQueueListIterable extension

Concatenate elements in nested iterable.
intercalate(Iterable<E> input, {int? count, int skip = 0, bool reverse = false}) QueueList<E>

Available on QueueList<Iterable<E>>, provided by the HeartQueueListIterable extension

Inserts an iterable in between iterables and concatenates the result.
zip() QueueList<QueueList<E>>

Available on QueueList<Iterable<E>>, provided by the HeartQueueListIterable extension

Pairs corresponding elements together.
zipWith<R>(R zipFunction(List<E>)) QueueList<R>

Available on QueueList<Iterable<E>>, provided by the HeartQueueListIterable extension

Returns an iterable by performing a function between corresponding elements of a nested iterable.