HeartQueueList<E> extension
Extension methods for QueueLists
- on
-
- QueueList<
E>
- QueueList<
Properties
-
ascending
→ QueueList<
E> -
Available on QueueList<
Returns a sorted iterable.E> , provided by the HeartQueueList extensionno setter -
backwards
→ QueueList<
E> -
Available on QueueList<
Reverses a ListE> , provided by the HeartQueueList extensionno setter -
descending
→ QueueList<
E> -
Available on QueueList<
Returns a sorted iterable in reverse order.E> , provided by the HeartQueueList extensionno setter -
inits
→ QueueList<
QueueList< E> > -
Available on QueueList<
Returns a nested iterable by adding one element at a time, starting from the beginning.E> , provided by the HeartQueueList extensionno setter -
tail
→ QueueList<
E> ? -
Available on QueueList<
Removes the first element, keeps the "tail".E> , provided by the HeartQueueList extensionno setter -
tails
→ QueueList<
QueueList< E> > -
Available on QueueList<
Returns a nested iterable by removing one element at a time, starting from the beginning.E> , provided by the HeartQueueList extensionno setter
Methods
-
addMissing(
Iterable< E> elements, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Adds elements fromE> , provided by the HeartQueueList extensionelementsthat are not in original value. -
after(
Iterable< E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Returns everything afterE> , provided by the HeartQueueList extensionsub.1, 2, 3.after(1) returns2, 3.1, 2, 3.after(1, 2) returns3.1, 2, 3.after([]) returns1, 2, 3. -
afterWhere(
bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) → QueueList< E> -
Available on QueueList<
Return everything after a condition is met.E> , provided by the HeartQueueList extension1, 2, 3, 4.afterWhere((e) => e.isOdd) returns2, 3, 4. -
before(
Iterable< E> sub, {int skip = 0, bool overlap = false, bool includeInResult = false, bool reverse = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Returns everything before a given input:E> , provided by the HeartQueueList extension1, 2, 3, 3.before(3, 3) returns1, 2.1, 2, 3, 3.before(1) returns [].1, 2, 3, 3.before([]) returns []. -
beforeWhere(
bool test(E e), {int skip = 0, bool includeInResult = false, bool reverse = false}) → QueueList< E> -
Available on QueueList<
Return everything before a condition is met.E> , provided by the HeartQueueList extension1, 2, 3.beforeWhere((e) => e == 3) returns1, 2. -
dropIndices(
Iterable< int> indicesToDrop) → QueueList<E> -
Available on QueueList<
Removes the elements at the given indices.E> , provided by the HeartQueueList extension -
group(
{bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList< QueueList< E> > -
Available on QueueList<
Items are grouped together if they are equal to the one next to it.E> , provided by the HeartQueueList extension -
groupBy(
bool groupFunction(dynamic a, dynamic b)) → QueueList< QueueList< E> > -
Available on QueueList<
Items are grouped together if they meet the criteria that compares consecutive elements.E> , provided by the HeartQueueList extension -
interleave(
Iterable< E> it) → QueueList<E> -
Available on QueueList<
Combines elements by taking turns. First element in original iterable is the first element of the result.E> , provided by the HeartQueueList extension -
intersperse(
Iterable< E> elementsToAdd, {int? count, int skip = 0, bool reverse = false}) → QueueList<E> -
Available on QueueList<
Inserts an element in between each element.E> , provided by the HeartQueueList extension -
keep(
Iterable< E> elementsToKeep, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Keeps all elements that are also inE> , provided by the HeartQueueList extensionelementsToKeep. -
keepIndices(
Iterable< int> indices) → QueueList<E> -
Available on QueueList<
Returns elements at the given indices.E> , provided by the HeartQueueList extension -
mode(
{bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList< E> -
Available on QueueList<
Returns the element(s) with the most occurrences.E> , provided by the HeartQueueList extension -
nub(
{Iterable< E> ? elementsToNub, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Removes duplicates.E> , provided by the HeartQueueList extension -
replace(
Iterable< E> from, Iterable<E> to, {int? count, int skip = 0, bool reverse = false, dynamic recursive = false, bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
ReplaceE> , provided by the HeartQueueList extensionfromwithto. -
riffleIn(
{bool inverse = false}) → QueueList< E> -
Available on QueueList<
Splits into two and uses interleave to combine, second half first.E> , provided by the HeartQueueList extension -
riffleOut(
{bool inverse = false}) → QueueList< E> -
Available on QueueList<
Splits into two and uses interleave to combine.E> , provided by the HeartQueueList extension -
splitAt(
int n) → QueueList< QueueList< E> > -
Available on QueueList<
Splits into two after firstE> , provided by the HeartQueueList extensionnelements. -
subtract(
Iterable< E> elementsToSubtract, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Removes elements one at a time if they are present.E> , provided by the HeartQueueList extension -
subtractAll(
Iterable< E> elementsToRemove, {bool equalityFunction(E a, E b) = h.symmetricDeepEquals}) → QueueList<E> -
Available on QueueList<
Removes all elements if they are inE> , provided by the HeartQueueList extensionelementsToRemove. -
toStrings(
) → QueueList< String> -
Available on QueueList<
Converts all elements to Strings.E> , provided by the HeartQueueList extension