HeartQueueListIterable<E> extension
Extension methods for iterables inside of a QueueList
Methods
-
concat(
) → QueueList< E> -
Available on QueueList<
Concatenate elements in nested iterable.Iterable< , provided by the HeartQueueListIterable extensionE> > -
intercalate(
Iterable< E> input, {int? count, int skip = 0, bool reverse = false}) → QueueList<E> -
Available on QueueList<
Inserts an iterable in between iterables and concatenates the result.Iterable< , provided by the HeartQueueListIterable extensionE> > -
zip(
) → QueueList< QueueList< E> > -
Available on QueueList<
Pairs corresponding elements together.Iterable< , provided by the HeartQueueListIterable extensionE> > -
zipWith<
R> (R zipFunction(List< E> )) → QueueList<R> -
Available on QueueList<
Returns an iterable by performing a function between corresponding elements of a nested iterable.Iterable< , provided by the HeartQueueListIterable extensionE> >